==> qtjambi-qt3drender-6.2.4-sources.jar: io/qt/qt3d/render/QColorMask.java <==
package io.qt.qt3d.render;


/**
 * <p>Allows specifying which color components should be written to the currently bound frame buffer</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html">Qt3DRender::QColorMask</a></p>
 */
public class QColorMask extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QColorMask.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#alphaMasked-prop">Qt3DRender::QColorMask::alphaMaskedChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="alphaMasked")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> alphaMaskedChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#blueMasked-prop">Qt3DRender::QColorMask::blueMaskedChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="blueMasked")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> blueMaskedChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#greenMasked-prop">Qt3DRender::QColorMask::greenMaskedChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="greenMasked")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> greenMaskedChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#redMasked-prop">Qt3DRender::QColorMask::redMaskedChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="redMasked")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> redMaskedChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QColorMask(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QColorMask() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#QColorMask">Qt3DRender::QColorMask::QColorMask(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QColorMask(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QColorMask instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#alphaMasked-prop">Qt3DRender::QColorMask::isAlphaMasked()const</a></p>
     */
    @io.qt.QtPropertyReader(name="alphaMasked")
    @io.qt.QtUninvokable
    public final boolean isAlphaMasked(){
        return isAlphaMasked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isAlphaMasked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#blueMasked-prop">Qt3DRender::QColorMask::isBlueMasked()const</a></p>
     */
    @io.qt.QtPropertyReader(name="blueMasked")
    @io.qt.QtUninvokable
    public final boolean isBlueMasked(){
        return isBlueMasked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isBlueMasked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#greenMasked-prop">Qt3DRender::QColorMask::isGreenMasked()const</a></p>
     */
    @io.qt.QtPropertyReader(name="greenMasked")
    @io.qt.QtUninvokable
    public final boolean isGreenMasked(){
        return isGreenMasked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isGreenMasked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#redMasked-prop">Qt3DRender::QColorMask::isRedMasked()const</a></p>
     */
    @io.qt.QtPropertyReader(name="redMasked")
    @io.qt.QtUninvokable
    public final boolean isRedMasked(){
        return isRedMasked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isRedMasked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#alphaMasked-prop">Qt3DRender::QColorMask::setAlphaMasked(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="alphaMasked")
    public final void setAlphaMasked(boolean alphaMasked){
        setAlphaMasked_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), alphaMasked);
    }
    
    private native void setAlphaMasked_native_bool(long __this__nativeId, boolean alphaMasked);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#blueMasked-prop">Qt3DRender::QColorMask::setBlueMasked(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="blueMasked")
    public final void setBlueMasked(boolean blueMasked){
        setBlueMasked_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), blueMasked);
    }
    
    private native void setBlueMasked_native_bool(long __this__nativeId, boolean blueMasked);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#greenMasked-prop">Qt3DRender::QColorMask::setGreenMasked(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="greenMasked")
    public final void setGreenMasked(boolean greenMasked){
        setGreenMasked_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), greenMasked);
    }
    
    private native void setGreenMasked_native_bool(long __this__nativeId, boolean greenMasked);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#redMasked-prop">Qt3DRender::QColorMask::setRedMasked(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="redMasked")
    public final void setRedMasked(boolean redMasked){
        setRedMasked_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), redMasked);
    }
    
    private native void setRedMasked_native_bool(long __this__nativeId, boolean redMasked);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QColorMask(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QColorMask(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QColorMask instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.2-sources.jar: io/qt/qt3d/render/QColorMask.java <==
package io.qt.qt3d.render;


/**
 * <p>Allows specifying which color components should be written to the currently bound frame buffer</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html">Qt3DRender::QColorMask</a></p>
 */
public class QColorMask extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QColorMask.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#alphaMasked-prop">Qt3DRender::QColorMask::alphaMaskedChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="alphaMasked")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> alphaMaskedChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#blueMasked-prop">Qt3DRender::QColorMask::blueMaskedChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="blueMasked")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> blueMaskedChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#greenMasked-prop">Qt3DRender::QColorMask::greenMaskedChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="greenMasked")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> greenMaskedChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#redMasked-prop">Qt3DRender::QColorMask::redMaskedChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="redMasked")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> redMaskedChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QColorMask(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QColorMask() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#QColorMask">Qt3DRender::QColorMask::QColorMask(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QColorMask(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QColorMask instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#alphaMasked-prop">Qt3DRender::QColorMask::isAlphaMasked()const</a></p>
     */
    @io.qt.QtPropertyReader(name="alphaMasked")
    @io.qt.QtUninvokable
    public final boolean isAlphaMasked(){
        return isAlphaMasked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isAlphaMasked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#blueMasked-prop">Qt3DRender::QColorMask::isBlueMasked()const</a></p>
     */
    @io.qt.QtPropertyReader(name="blueMasked")
    @io.qt.QtUninvokable
    public final boolean isBlueMasked(){
        return isBlueMasked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isBlueMasked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#greenMasked-prop">Qt3DRender::QColorMask::isGreenMasked()const</a></p>
     */
    @io.qt.QtPropertyReader(name="greenMasked")
    @io.qt.QtUninvokable
    public final boolean isGreenMasked(){
        return isGreenMasked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isGreenMasked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#redMasked-prop">Qt3DRender::QColorMask::isRedMasked()const</a></p>
     */
    @io.qt.QtPropertyReader(name="redMasked")
    @io.qt.QtUninvokable
    public final boolean isRedMasked(){
        return isRedMasked_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isRedMasked_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#alphaMasked-prop">Qt3DRender::QColorMask::setAlphaMasked(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="alphaMasked")
    public final void setAlphaMasked(boolean alphaMasked){
        setAlphaMasked_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), alphaMasked);
    }
    
    private native void setAlphaMasked_native_bool(long __this__nativeId, boolean alphaMasked);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#blueMasked-prop">Qt3DRender::QColorMask::setBlueMasked(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="blueMasked")
    public final void setBlueMasked(boolean blueMasked){
        setBlueMasked_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), blueMasked);
    }
    
    private native void setBlueMasked_native_bool(long __this__nativeId, boolean blueMasked);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#greenMasked-prop">Qt3DRender::QColorMask::setGreenMasked(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="greenMasked")
    public final void setGreenMasked(boolean greenMasked){
        setGreenMasked_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), greenMasked);
    }
    
    private native void setGreenMasked_native_bool(long __this__nativeId, boolean greenMasked);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qcolormask.html#redMasked-prop">Qt3DRender::QColorMask::setRedMasked(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="redMasked")
    public final void setRedMasked(boolean redMasked){
        setRedMasked_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), redMasked);
    }
    
    private native void setRedMasked_native_bool(long __this__nativeId, boolean redMasked);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QColorMask(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QColorMask(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QColorMask instance, QDeclarativeConstructor constructor);
    
}
